Huggingface Transformers
========================

.. currentmodule:: xpmir.text.huggingface

.. autoxpmconfig:: BaseTransformer

Encoders
========

.. autoxpmconfig:: TransformerEncoder
.. autoxpmconfig:: TransformerTokensEncoder
.. autoxpmconfig:: TransformerTextEncoderAdapter

.. autoxpmconfig:: DualTransformerEncoder
.. autoxpmconfig:: SentenceTransformerTextEncoder
.. autoxpmconfig:: OneHotHuggingFaceEncoder
.. autoxpmconfig:: DualDuoBertTransformerEncoder

.. autoxpmconfig:: TransformerVocab

.. autoxpmconfig:: TransformerTokensEncoderWithMLMOutput

Tokenizers
==========

.. autoxpmconfig:: OneHotHuggingFaceEncoder
.. autoxpmconfig:: HuggingfaceTokenizer

Masked-LM
=========

.. autoxpmconfig:: MLMEncoder

Hooks
=====

.. autoxpmconfig:: LayerSelector
